summaryrefslogtreecommitdiffstats
path: root/kandy/src/cmdpropertiesdialog.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kandy/src/cmdpropertiesdialog.cpp')
-rw-r--r--kandy/src/cmdpropertiesdialog.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/kandy/src/cmdpropertiesdialog.cpp b/kandy/src/cmdpropertiesdialog.cpp
index f9667c26..b71a62f2 100644
--- a/kandy/src/cmdpropertiesdialog.cpp
+++ b/kandy/src/cmdpropertiesdialog.cpp
@@ -18,8 +18,8 @@
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
As a special exception, permission is given to link this program
- with any edition of Qt, and distribute the resulting executable,
- without including the source code for Qt in the source distribution.
+ with any edition of TQt, and distribute the resulting executable,
+ without including the source code for TQt in the source distribution.
*/
#include <tqlistview.h>
@@ -36,8 +36,8 @@
class ParameterItem : public TQCheckListItem {
public:
- ParameterItem(ATParameter *p,TQListView *parent) :
- TQCheckListItem(parent,p->name(),CheckBox),mParameter(p)
+ ParameterItem(ATParameter *p,TQListView *tqparent) :
+ TQCheckListItem(tqparent,p->name(),CheckBox),mParameter(p)
{
setText(1,p->value());
setOn(p->userInput());
@@ -56,16 +56,16 @@ class ParameterItem : public TQCheckListItem {
/*
* Constructs a CmdPropertiesDialog which is a child of 'parent', with the
* name 'name' and widget flags set to 'f'
*
* The dialog will by default be modeless, unless you set 'modal' to
* TRUE to construct a modal dialog.
*/
-CmdPropertiesDialog::CmdPropertiesDialog(ATCommand *cmd, TQWidget* parent,
+CmdPropertiesDialog::CmdPropertiesDialog(ATCommand *cmd, TQWidget* tqparent,
const char* name, bool modal,
WFlags fl )
- : CmdPropertiesDialog_base( parent, name, modal, fl )
+ : CmdPropertiesDialog_base( tqparent, name, modal, fl )
{
mCmd = cmd;
@@ -105,7 +105,7 @@ void CmdPropertiesDialog::editParameterName(TQListViewItem *item)
{
bool ok = false;
- TQString newName = KInputDialog::getText(TQString::null,
+ TQString newName = KInputDialog::getText(TQString(),
i18n("Enter parameter name:"),item->text(0),&ok,this);
if (ok) {
@@ -56,16 +56,16 @@ class ParameterItem : public TQCheckListItem {
/*
- * Constructs a CmdPropertiesDialog which is a child of 'parent', with the
+ * Constructs a CmdPropertiesDialog which is a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'
*